@@ -1,8 +1,7 @@
-# Copyright 2022 Oliver Smith
+# Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import os
 import logging
-import pmb.aportgen.binutils
 import pmb.aportgen.busybox_static
 import pmb.aportgen.device
 import pmb.aportgen.gcc
@@ -13,6 +12,18 @@ import pmb.config
 import pmb.helpers.cli
 
 
+def get_cross_package_arches(pkgname):
+    """
+    Get the arches for which we want to build cross packages.
+    :param pkgname: package name, e.g. "gcc-aarch64", "gcc-x86_64"
+    :returns: string of architecture(s) (space separated)
+    """
+    if pkgname.endswith("-x86_64"):
+        return "aarch64"
+    else:
+        return "x86_64"
+
+
 def properties(pkgname):
     """
     Get the `pmb.config.aportgen` properties for the aport generator, based on
