@@ -16,7 +16,7 @@ def ask_for_architecture():
         architectures.remove("armhf")
     while True:
         ret = pmb.helpers.cli.ask("Device architecture", architectures,
-                                  architectures[0], complete=architectures)
+                                  "aarch64", complete=architectures)
         if ret in architectures:
             return ret
         logging.fatal("ERROR: Invalid architecture specified. If you want to"
@@ -73,7 +73,8 @@ def ask_for_flash_method():
         logging.info("Which flash method does the device support?")
         method = pmb.helpers.cli.ask("Flash method",
                                      pmb.config.flash_methods,
-                                     pmb.config.flash_methods[0])
+                                     "none",
+                                     complete=pmb.config.flash_methods)
 
         if method in pmb.config.flash_methods:
             if method == "heimdall":
@@ -120,24 +121,33 @@ def generate_deviceinfo_fastboot_content(bootimg=None):
     if bootimg is None:
         bootimg = {"cmdline": "",
                    "qcdt": "false",
-                   "mtk_mkimage": "false",
                    "dtb_second": "false",
                    "base": "",
                    "kernel_offset": "",
                    "ramdisk_offset": "",
                    "second_offset": "",
                    "tags_offset": "",
-                   "pagesize": "2048"}
+                   "pagesize": "2048",
+                   "mtk_label_kernel": "",
+                   "mtk_label_ramdisk": ""}
 
     content = f"""\
         deviceinfo_kernel_cmdline="{bootimg["cmdline"]}"
         deviceinfo_generate_bootimg="true"
         deviceinfo_bootimg_qcdt="{bootimg["qcdt"]}"
-        deviceinfo_bootimg_mtk_mkimage="{bootimg["mtk_mkimage"]}"
         deviceinfo_bootimg_dtb_second="{bootimg["dtb_second"]}"
         deviceinfo_flash_pagesize="{bootimg["pagesize"]}"
         """
 
+    if "mtk_label_kernel" in bootimg.keys():
+        content += f"""\
+        deviceinfo_mtk_label_kernel="{bootimg["mtk_label_kernel"]}"
+        """
+    if "mtk_label_ramdisk" in bootimg.keys():
+        content += f"""\
+        deviceinfo_mtk_label_ramdisk="{bootimg["mtk_label_ramdisk"]}"
+        """
+
     if "header_version" in bootimg.keys():
         content += f"""\
         deviceinfo_header_version="{bootimg["header_version"]}"
@@ -178,7 +188,6 @@ def generate_deviceinfo(args, pkgname, name, manufacturer, year, arch,
         deviceinfo_codename="{codename}"
         deviceinfo_year="{year}"
         deviceinfo_dtb=""
-        deviceinfo_modules_initfs=""
         deviceinfo_arch="{arch}"
 
         # Device related
@@ -194,13 +203,13 @@ def generate_deviceinfo(args, pkgname, name, manufacturer, year, arch,
 
     content_heimdall_bootimg = """\
         deviceinfo_flash_heimdall_partition_kernel=""
-        deviceinfo_flash_heimdall_partition_system=""
+        deviceinfo_flash_heimdall_partition_rootfs=""
         """
 
     content_heimdall_isorec = """\
         deviceinfo_flash_heimdall_partition_kernel=""
         deviceinfo_flash_heimdall_partition_initfs=""
-        deviceinfo_flash_heimdall_partition_system=""
+        deviceinfo_flash_heimdall_partition_rootfs=""
         """
 
     content_0xffff = """\
@@ -231,6 +240,27 @@ def generate_deviceinfo(args, pkgname, name, manufacturer, year, arch,
             handle.write(line.lstrip() + "\n")
 
 
+def generate_modules_initfs(args):
+    content = """\
+    # Remove this file if unnecessary (CHANGEME!)
+    # This file shall contain a list of modules to be included in the initramfs,
+    # so that they are available in early boot stages. In general, it should
+    # include modules to support unlocking FDE (touchscreen, panel, etc),
+    # USB networking, and telnet in the debug-shell.
+    # The format is one module name per line. Lines starting with the character
+    # '#', and empty lines are ignored. If there are multiple kernel variants
+    # with different initramfs module requirements, one modules-initfs.$variant
+    # file should be created for each of them.
+    """
+
+    # Write to file
+    pmb.helpers.run.user(args, ["mkdir", "-p", args.work + "/aportgen"])
+    path = args.work + "/aportgen/modules-initfs"
+    with open(path, "w", encoding="utf-8") as handle:
+        for line in content.rstrip().split("\n"):
+            handle.write(line.lstrip() + "\n")
+
+
 def generate_apkbuild(args, pkgname, name, arch, flash_method):
     # Dependencies
     depends = ["postmarketos-base",
@@ -257,7 +287,10 @@ def generate_apkbuild(args, pkgname, name, arch, flash_method):
             {depends}
         "
         makedepends="devicepkg-dev"
-        source="deviceinfo"
+        source="
+            deviceinfo
+            modules-initfs
+        "
 
         build() {{
             devicepkg_build $startdir $pkgname
@@ -294,4 +327,5 @@ def generate(args, pkgname):
     generate_deviceinfo(args, pkgname, name, manufacturer, year, arch,
                         chassis, has_keyboard, has_external_storage,
                         flash_method, bootimg)
+    generate_modules_initfs(args)
     generate_apkbuild(args, pkgname, name, arch, flash_method)
