@@ -1,4 +1,4 @@
-# Copyright 2021 Oliver Smith
+# Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import pmb.aportgen.core
 import pmb.helpers.git
@@ -23,22 +23,21 @@ def generate(args, pkgname):
                          " gcc6.")
     pmb.helpers.run.user(args, ["cp", "-r", upstream, f"{args.work}/aportgen"])
 
-    # Rewrite APKBUILD (only building for native covers most use cases and
-    # saves a lot of build time, can be changed on demand)
+    # Rewrite APKBUILD
     fields = {
         "pkgname": pkgname,
         "pkgdesc": f"Stage2 cross-compiler for {arch}",
-        "arch": pmb.config.arch_native,
-        "depends": f"isl binutils-{arch} mpc1",
+        "arch": pmb.aportgen.get_cross_package_arches(pkgname),
+        "depends": f"binutils-{arch} mpc1",
         "makedepends_build": "gcc g++ bison flex texinfo gawk zip"
                              " gmp-dev mpfr-dev mpc1-dev zlib-dev",
         "makedepends_host": "linux-headers gmp-dev mpfr-dev mpc1-dev isl-dev"
                             f" zlib-dev musl-dev-{arch} binutils-{arch}",
-        "subpackages": f"g++-{arch}:gpp" if prefix == "gcc" else "",
+        "subpackages": "",
 
         # gcc6: options is already there, so we need to replace it and not only
         # set it below the header like done below.
-        "options": "!strip !tracedeps",
+        "options": "!strip",
 
         "LIBGOMP": "false",
         "LIBGCC": "false",
@@ -46,6 +45,11 @@ def generate(args, pkgname):
         "LIBITM": "false",
     }
 
+    # Latest gcc only, not gcc4 and gcc6
+    if prefix == "gcc":
+        fields["subpackages"] = f"g++-{arch}:gpp" \
+                                f" libstdc++-dev-{arch}:libcxx_dev"
+
     below_header = "CTARGET_ARCH=" + arch + """
         CTARGET="$(arch_to_hostspec ${CTARGET_ARCH})"
         LANG_D=false
@@ -54,7 +58,7 @@ def generate(args, pkgname):
         LANG_GO=false
         LANG_FORTRAN=false
         LANG_ADA=false
-        options="!strip !tracedeps"
+        options="!strip"
 
         # abuild doesn't try to tries to install "build-base-$CTARGET_ARCH"
         # when this variable matches "no*"
@@ -78,6 +82,9 @@ def generate(args, pkgname):
         # use CBUILDROOT as sysroot. In the original APKBUILD this is a local
         # variable, but we make it a global one.
         '*_cross_configure=*': None,
+
+        # Do not build foreign arch libgcc, we use the one from Alpine (#2168)
+        '_libgcc=true*': '_libgcc=false',
     }
 
     pmb.aportgen.core.rewrite(args, pkgname, based_on, fields,
