@@ -1,4 +1,4 @@
-# Copyright 2022 Oliver Smith
+# Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import os
 import logging
@@ -143,7 +143,7 @@ def packages_get_locally_built_apks(args, packages, arch):
     :param packages: list of pkgnames
     :param arch: architecture that the locally built packages should have
     :returns: list of apk file paths that are valid inside the chroots, e.g.
-              ["/mnt/pmbootstrap-packages/x86_64/hello-world-1-r6.apk", ...]
+              ["/mnt/pmbootstrap/packages/x86_64/hello-world-1-r6.apk", ...]
     """
     channel = pmb.config.pmaports.read_config(args)["channel"]
     ret = []
@@ -157,7 +157,7 @@ def packages_get_locally_built_apks(args, packages, arch):
         if not os.path.exists(f"{args.work}/packages/{channel}/{arch}/{apk_file}"):
             continue
 
-        ret.append(f"/mnt/pmbootstrap-packages/{arch}/{apk_file}")
+        ret.append(f"/mnt/pmbootstrap/packages/{arch}/{apk_file}")
 
     return ret
 
@@ -192,6 +192,10 @@ def install_run_apk(args, to_add, to_add_local, to_del, suffix):
         commands += [["del"] + to_del]
 
     for (i, command) in enumerate(commands):
+        # --no-interactive is a parameter to `add`, so it must be appended or apk
+        # gets confused
+        command += ["--no-interactive"]
+
         if args.offline:
             command = ["--no-network"] + command
         if i == 0:
