@@ -4,6 +4,7 @@ import multiprocessing
 import os
 import pmb.parse.arch
 import sys
+from typing import List
 
 #
 # Exported functions
@@ -17,7 +18,6 @@ from pmb.config.sudo import which_sudo
 #
 # Exported variables (internal configuration)
 #
-version = "1.51.0"
 pmb_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 apk_keys_path = pmb_src + "/pmb/data/keys"
 arch_native = pmb.parse.arch.alpine_native()
@@ -27,7 +27,9 @@ arch_native = pmb.parse.arch.alpine_native()
 # Update this frequently to prevent a MITM attack with an outdated version
 # (which may contain a vulnerable apk/openssl, and allows an attacker to
 # exploit the system!)
-apk_tools_min_version = {"edge": "2.12.11-r0",
+apk_tools_min_version = {"edge": "2.14.0-r5",
+                         "v3.19": "2.14.0-r5",
+                         "v3.18": "2.14.0-r2",
                          "v3.17": "2.12.10-r1",
                          "v3.16": "2.12.9-r3",
                          "v3.15": "2.12.7-r3",
@@ -58,35 +60,47 @@ required_programs = [
     "ps",
     "tar",
 ]
-sudo = which_sudo()
+
+
+def sudo(cmd: List[str]) -> List[str]:
+    """Adapt a command to run as root."""
+    sudo = which_sudo()
+    if sudo:
+        return [sudo, *cmd]
+    else:
+        return cmd
+
 
 # Keys saved in the config file (mostly what we ask in 'pmbootstrap init')
-config_keys = ["aports",
-               "ccache_size",
-               "device",
-               "extra_packages",
-               "hostname",
-               "build_pkgs_on_install",
-               "is_default_channel",
-               "jobs",
-               "kernel",
-               "keymap",
-               "locale",
-               "mirror_alpine",
-               "mirrors_postmarketos",
-               "nonfree_firmware",
-               "nonfree_userland",
-               "ssh_keys",
-               "ssh_key_glob",
-               "timezone",
-               "ui",
-               "ui_extras",
-               "user",
-               "work",
-               "boot_size",
-               "extra_space",
-               "sudo_timer",
-               "qemu_redir_stdio"]
+config_keys = [
+    "aports",
+    "boot_size",
+    "build_default_device_arch",
+    "build_pkgs_on_install",
+    "ccache_size",
+    "device",
+    "extra_packages",
+    "extra_space",
+    "hostname",
+    "is_default_channel",
+    "jobs",
+    "kernel",
+    "keymap",
+    "locale",
+    "mirror_alpine",
+    "mirrors_postmarketos",
+    "nonfree_firmware",
+    "nonfree_userland",
+    "qemu_redir_stdio",
+    "ssh_key_glob",
+    "ssh_keys",
+    "sudo_timer",
+    "timezone",
+    "ui",
+    "ui_extras",
+    "user",
+    "work",
+]
 
 # Config file/commandline default values
 # $WORK gets replaced with the actual value for args.work (which may be
@@ -110,7 +124,7 @@ defaults = {
     "jobs": str(multiprocessing.cpu_count() + 1),
     "kernel": "stable",
     "keymap": "",
-    "locale": "C.UTF-8",
+    "locale": "en_US.UTF-8",
     "log": "$WORK/log.txt",
     "mirror_alpine": "http://dl-cdn.alpinelinux.org/alpine/",
     # NOTE: mirrors_postmarketos variable type is supposed to be
@@ -118,18 +132,18 @@ defaults = {
     "mirrors_postmarketos": "http://mirror.postmarketos.org/postmarketos/",
     "nonfree_firmware": True,
     "nonfree_userland": False,
-    "port_distccd": "33632",
     "ssh_keys": False,
     "ssh_key_glob": "~/.ssh/id_*.pub",
     "timezone": "GMT",
-    "ui": "weston",
+    "ui": "console",
     "ui_extras": False,
     "user": "user",
     "work": os.path.expanduser("~") + "/.local/var/pmbootstrap",
     "boot_size": "256",
     "extra_space": "0",
     "sudo_timer": False,
-    "qemu_redir_stdio": False
+    "qemu_redir_stdio": False,
+    "build_default_device_arch": False,
 }
 
 
@@ -154,26 +168,6 @@ if "NO_COLOR" in os.environ:
     for style in styles.keys():
         styles[style] = ""
 
-
-# List of available locales taken from musl-locales package; see
-# https://pkgs.alpinelinux.org/contents?name=musl-locales
-locales = [
-    "C.UTF-8",
-    "ch_DE.UTF-8",
-    "de_CH.UTF-8",
-    "de_DE.UTF-8",
-    "en_GB.UTF-8",
-    "en_US.UTF-8",
-    "es_ES.UTF-8",
-    "fr_FR.UTF-8",
-    "it_IT.UTF-8",
-    "nb_NO.UTF-8",
-    "nl_NL.UTF-8",
-    "pt_BR.UTF-8",
-    "ru_RU.UTF-8",
-    "sv_SE.UTF-8"
-]
-
 # Supported filesystems and their fstools packages
 filesystems = {"btrfs": "btrfs-progs",
                "ext2": "e2fsprogs",
@@ -213,17 +207,21 @@ chroot_host_path = os.environ["PATH"] + ":/usr/sbin/"
 # $WORK gets replaced with args.work
 # $ARCH gets replaced with the chroot architecture (eg. x86_64, armhf)
 # $CHANNEL gets replaced with the release channel (e.g. edge, v21.03)
+# Use no more than one dir after /mnt/pmbootstrap, see remove_mnt_pmbootstrap.
 chroot_mount_bind = {
     "/proc": "/proc",
     "$WORK/cache_apk_$ARCH": "/var/cache/apk",
-    "$WORK/cache_ccache_$ARCH": "/mnt/pmbootstrap-ccache",
+    "$WORK/cache_appstream/$ARCH/$CHANNEL": "/mnt/appstream-data",
+    "$WORK/cache_ccache_$ARCH": "/mnt/pmbootstrap/ccache",
     "$WORK/cache_distfiles": "/var/cache/distfiles",
-    "$WORK/cache_git": "/mnt/pmbootstrap-git",
-    "$WORK/cache_rust": "/mnt/pmbootstrap-rust",
-    "$WORK/config_abuild": "/mnt/pmbootstrap-abuild-config",
+    "$WORK/cache_git": "/mnt/pmbootstrap/git",
+    "$WORK/cache_go": "/mnt/pmbootstrap/go",
+    "$WORK/cache_rust": "/mnt/pmbootstrap/rust",
+    "$WORK/config_abuild": "/mnt/pmbootstrap/abuild-config",
     "$WORK/config_apk_keys": "/etc/apk/keys",
-    "$WORK/images_netboot": "/mnt/pmbootstrap-netboot",
-    "$WORK/packages/$CHANNEL": "/mnt/pmbootstrap-packages",
+    "$WORK/cache_sccache": "/mnt/pmbootstrap/sccache",
+    "$WORK/images_netboot": "/mnt/pmbootstrap/netboot",
+    "$WORK/packages/$CHANNEL": "/mnt/pmbootstrap/packages",
 }
 
 # Building chroots (all chroots, except for the rootfs_ chroot) get symlinks in
@@ -234,13 +232,20 @@ chroot_mount_bind = {
 # a no-go, but at least until this is resolved properly, let's cache the
 # dependencies and downloads as suggested in "Caching the Cargo home in CI":
 # https://doc.rust-lang.org/cargo/guide/cargo-home.html
+# Go: cache the directories "go env GOMODCACHE" and "go env GOCACHE" point to,
+# to avoid downloading dependencies over and over (GOMODCACHE, similar to the
+# rust depends caching described above) and to cache build artifacts (GOCACHE,
+# similar to ccache).
 chroot_home_symlinks = {
-    "/mnt/pmbootstrap-abuild-config": "/home/pmos/.abuild",
-    "/mnt/pmbootstrap-ccache": "/home/pmos/.ccache",
-    "/mnt/pmbootstrap-packages": "/home/pmos/packages/pmos",
-    "/mnt/pmbootstrap-rust/registry/index": "/home/pmos/.cargo/registry/index",
-    "/mnt/pmbootstrap-rust/registry/cache": "/home/pmos/.cargo/registry/cache",
-    "/mnt/pmbootstrap-rust/git/db": "/home/pmos/.cargo/git/db",
+    "/mnt/pmbootstrap/abuild-config": "/home/pmos/.abuild",
+    "/mnt/pmbootstrap/ccache": "/home/pmos/.ccache",
+    "/mnt/pmbootstrap/go/gocache": "/home/pmos/.cache/go-build",
+    "/mnt/pmbootstrap/go/gomodcache": "/home/pmos/go/pkg/mod",
+    "/mnt/pmbootstrap/packages": "/home/pmos/packages/pmos",
+    "/mnt/pmbootstrap/rust/git/db": "/home/pmos/.cargo/git/db",
+    "/mnt/pmbootstrap/rust/registry/cache": "/home/pmos/.cargo/registry/cache",
+    "/mnt/pmbootstrap/rust/registry/index": "/home/pmos/.cargo/registry/index",
+    "/mnt/pmbootstrap/sccache": "/home/pmos/.cache/sccache",
 }
 
 # Device nodes to be created in each chroot. Syntax for each entry:
@@ -266,8 +271,8 @@ chroot_outdated = 3600 * 24 * 2
 #
 # Officially supported host/target architectures for postmarketOS. Only
 # specify architectures supported by Alpine here. For cross-compiling,
-# we need to generate the "musl-$ARCH", "binutils-$ARCH" and "gcc-$ARCH"
-# packages (use "pmbootstrap aportgen musl-armhf" etc.).
+# we need to generate the "musl-$ARCH" and "gcc-$ARCH" packages (use
+# "pmbootstrap aportgen musl-armhf" etc.).
 build_device_architectures = ["armhf", "armv7", "aarch64", "x86_64", "x86", "riscv64"]
 
 # Packages that will be installed in a chroot before it builds packages
@@ -290,7 +295,7 @@ build_packages = ["abuild", "build-base", "ccache", "git"]
 #     this e.g. if the order of the elements is important.
 
 # Necessary kernel config options
-necessary_kconfig_options = {
+kconfig_options = {
     ">=0.0.0": {  # all versions
         "all": {  # all arches
             "ANDROID_PARANOID_NETWORK": False,
@@ -311,6 +316,16 @@ necessary_kconfig_options = {
             "VT": True,
         }
     },
+    ">=2.6.0": {
+        "all": {
+            "BINFMT_ELF": True,
+        },
+    },
+    ">=3.10.0": {
+        "all": {
+            "BINFMT_SCRIPT": True,
+        },
+    },
     ">=4.0.0": {
         "all": {
             "UEVENT_HELPER": True,
@@ -336,26 +351,31 @@ necessary_kconfig_options = {
 }
 
 # Necessary waydroid kernel config options (android app support)
-necessary_kconfig_options_waydroid = {
+kconfig_options_waydroid = {
     ">=0.0.0": {  # all versions
         "all": {  # all arches
-            "SQUASHFS": True,
-            "SQUASHFS_XZ": True,
-            "SQUASHFS_XATTR": True,
-            "TMPFS_XATTR": True,
-            "ANDROID_BINDER_IPC": True,
             "ANDROID_BINDERFS": False,
             "ANDROID_BINDER_DEVICES": ["binder", "hwbinder", "vndbinder"],
+            "ANDROID_BINDER_IPC": True,
+            "ANDROID_BINDER_IPC_SELFTEST": False,
+            "BLK_DEV_LOOP": True,
+            "BPF_SYSCALL": True,
+            "BRIDGE": True,
+            "BRIDGE_VLAN_FILTERING": True,
+            "CGROUP_BPF": True,
+            "FUSE_FS": True,
+            "IP_NF_MANGLE": True,
             "NETFILTER_XTABLES": True,
             "NETFILTER_XT_MATCH_COMMENT": True,
-            "IP_NF_MANGLE": True,
-            "FUSE_FS": True,
-            "BLK_DEV_LOOP": True,
+            "PSI": True,
+            "PSI_DEFAULT_DISABLED": False,
+            "SQUASHFS": True,
+            "SQUASHFS_XATTR": True,
+            "SQUASHFS_XZ": True,
+            "TMPFS_XATTR": True,
             "TUN": True,
             "VETH": True,
             "VLAN_8021Q": True,  # prerequisite for bridge
-            "BRIDGE": True,
-            "BRIDGE_VLAN_FILTERING": True,
         }
     },
     ">=3.5": {
@@ -378,7 +398,7 @@ necessary_kconfig_options_waydroid = {
 
 # Necessary iwd kernel config options (inet wireless daemon)
 # Obtained from 'grep ADD_MISSING src/main.c' in iwd.git
-necessary_kconfig_options_iwd = {
+kconfig_options_iwd = {
     ">=0.0.0": {  # all versions
         "all": {  # all arches
             "ASYMMETRIC_KEY_TYPE": True,
@@ -400,12 +420,13 @@ necessary_kconfig_options_iwd = {
             "PKCS7_MESSAGE_PARSER": True,
             "PKCS8_PRIVATE_KEY_PARSER": True,
             "X509_CERTIFICATE_PARSER": True,
+            "RFKILL": True,
         },
     },
 }
 
 # Necessary nftables kernel config options (firewall)
-necessary_kconfig_options_nftables = {
+kconfig_options_nftables = {
     ">=3.13.0": {  # nftables support introduced here
         "all": {  # all arches
             "NETFILTER": True,
@@ -440,7 +461,7 @@ necessary_kconfig_options_nftables = {
 }
 
 # Necessary kernel config options for containers (lxc, Docker)
-necessary_kconfig_options_containers = {
+kconfig_options_containers = {
     ">=0.0.0": {  # all versions, more specifically - since >=2.5~2.6
         "all": {  # all arches
             "NAMESPACES": True,
@@ -556,7 +577,7 @@ necessary_kconfig_options_containers = {
 }
 
 # Necessary zram kernel config options (RAM disk with on-the-fly compression)
-necessary_kconfig_options_zram = {
+kconfig_options_zram = {
     ">=3.14.0": {  # zram support introduced here
         "all": {  # all arches
             "ZRAM": True,
@@ -569,7 +590,7 @@ necessary_kconfig_options_zram = {
 }
 
 # Necessary netboot kernel config options
-necessary_kconfig_options_netboot = {
+kconfig_options_netboot = {
     ">=0.0.0": {  # all versions
         "all": {  # all arches
             "BLK_DEV_NBD": True,
@@ -579,7 +600,7 @@ necessary_kconfig_options_netboot = {
 
 # Necessary wireguard & wg-quick kernel config options
 # From https://gitweb.gentoo.org/repo/gentoo.git/tree/net-vpn/wireguard-tools/wireguard-tools-1.0.20210914.ebuild?id=76aaa1eeb6f001baaa68e6946f917ebb091bbd9d # noqa
-necessary_kconfig_options_wireguard = {
+kconfig_options_wireguard = {
     ">=5.6_rc1": {  # all versions
         "all": {  # all arches
             "WIREGUARD": True,
@@ -599,7 +620,7 @@ necessary_kconfig_options_wireguard = {
 }
 
 # Necessary file system config options
-necessary_kconfig_options_filesystems = {
+kconfig_options_filesystems = {
     ">=0.0.0": {  # all versions
         "all": {  # all arches
             "BTRFS_FS": True,
@@ -610,8 +631,23 @@ necessary_kconfig_options_filesystems = {
     },
 }
 
+kconfig_options_usb_gadgets = {
+    ">=0.0.0": {  # all versions
+        "all": {  # all arches
+            # disable legacy gadgets
+            "USB_ETH": False,
+            "USB_FUNCTIONFS": False,
+            "USB_MASS_STORAGE": False,
+            "USB_G_SERIAL": False,
+            # enable configfs gadgets
+            "USB_CONFIGFS_NCM": True,  # USB networking via NCM
+            "USB_CONFIGFS_RNDIS": True,  # USB networking via RNDIS (legacy)
+        },
+    },
+}
+
 # Various other kernel config options
-necessary_kconfig_options_community = {
+kconfig_options_community = {
     ">=0.0.0": {  # all versions
         "all": {  # all arches
             "INPUT_UINPUT": True,  # buffyboard
@@ -623,7 +659,7 @@ necessary_kconfig_options_community = {
 }
 
 # Necessary UEFI boot config options
-necessary_kconfig_options_uefi = {
+kconfig_options_uefi = {
     ">=0.0.0": {  # all versions
         "all": {  # all arches
             "EFI_STUB": True,
@@ -634,7 +670,16 @@ necessary_kconfig_options_uefi = {
             "EFI_PARAMS_FROM_FDT": True,
             "EFI_RUNTIME_WRAPPERS": True,
             "EFI_GENERIC_STUB": True,
-        }
+        },
+        "x86_64": {
+            "EFI_MIXED": True,
+        },
+    },
+    ">=6.1.0": {
+        "aarch64": {
+            # Required EFI booting compressed kernels on this arch
+            "EFI_ZBOOT": True,
+        },
     },
 }
 
@@ -695,6 +740,9 @@ apkbuild_attributes = {
     "_outdir": {},
     "_config": {},
 
+    # linux-edge
+    "_depends_dev": {"array": True},
+
     # mesa
     "_llvmver": {},
 
@@ -714,7 +762,7 @@ apkbuild_attributes = {
 # Reference: https://postmarketos.org/apkbuild-options
 apkbuild_custom_valid_options = [
     "!pmb:crossdirect",
-    "!pmb:kconfig-check",
+    "!pmb:kconfigcheck",
     "pmb:kconfigcheck-community",
     "pmb:kconfigcheck-containers",
     "pmb:kconfigcheck-iwd",
@@ -737,7 +785,6 @@ deviceinfo_attributes = [
     "codename",
     "year",
     "dtb",
-    "modules_initfs",
     "arch",
 
     # device
@@ -757,19 +804,30 @@ deviceinfo_attributes = [
     # flash
     "flash_heimdall_partition_kernel",
     "flash_heimdall_partition_initfs",
-    "flash_heimdall_partition_system",
+    "flash_heimdall_partition_rootfs",
+    "flash_heimdall_partition_system", # deprecated
     "flash_heimdall_partition_vbmeta",
     "flash_heimdall_partition_dtbo",
     "flash_fastboot_partition_kernel",
-    "flash_fastboot_partition_system",
+    "flash_fastboot_partition_rootfs",
+    "flash_fastboot_partition_system", # deprecated
     "flash_fastboot_partition_vbmeta",
     "flash_fastboot_partition_dtbo",
+    "flash_rk_partition_kernel",
+    "flash_rk_partition_rootfs",
+    "flash_rk_partition_system", # deprecated
+    "flash_mtkclient_partition_kernel",
+    "flash_mtkclient_partition_rootfs",
+    "flash_mtkclient_partition_vbmeta",
+    "flash_mtkclient_partition_dtbo",
     "generate_legacy_uboot_initfs",
     "kernel_cmdline",
     "generate_bootimg",
     "header_version",
     "bootimg_qcdt",
-    "bootimg_mtk_mkimage",
+    "bootimg_mtk_mkimage", # deprecated
+    "bootimg_mtk_label_kernel",
+    "bootimg_mtk_label_ramdisk",
     "bootimg_dtb_second",
     "bootimg_custom_args",
     "flash_offset_base",
@@ -801,7 +859,7 @@ deviceinfo_attributes = [
     "keymaps",
 ]
 
-# Valid types for the 'chassis' atribute in deviceinfo
+# Valid types for the 'chassis' attribute in deviceinfo
 # See https://www.freedesktop.org/software/systemd/man/machine-info.html
 deviceinfo_chassis_types = [
     "desktop",
@@ -832,9 +890,6 @@ default_ip = "172.16.42.1"
 install_native_packages = ["cryptsetup", "util-linux", "parted"]
 install_device_packages = ["postmarketos-base"]
 
-# Groups for the default user
-install_user_groups = ["wheel", "video", "audio", "input", "plugdev", "netdev"]
-
 #
 # FLASH
 #
@@ -843,6 +898,7 @@ flash_methods = [
     "0xffff",
     "fastboot",
     "heimdall",
+    "mtkclient",
     "none",
     "rkdeveloptool",
     "uuu",
@@ -867,7 +923,7 @@ $IMAGE: Path to the combined boot/rootfs image
 $IMAGE_SPLIT_BOOT: Path to the (split) boot image
 $IMAGE_SPLIT_ROOT: Path to the (split) rootfs image
 $PARTITION_KERNEL: Partition to flash the kernel/boot.img to
-$PARTITION_SYSTEM: Partition to flash the rootfs to
+$PARTITION_ROOTFS: Partition to flash the rootfs to
 
 Fastboot specific: $KERNEL_CMDLINE
 Heimdall specific: $PARTITION_INITFS
@@ -878,7 +934,7 @@ flashers = {
         "depends": [],  # pmaports.cfg: supported_fastboot_depends
         "actions": {
             "list_devices": [["fastboot", "devices", "-l"]],
-            "flash_rootfs": [["fastboot", "flash", "$PARTITION_SYSTEM",
+            "flash_rootfs": [["fastboot", "flash", "$PARTITION_ROOTFS",
                               "$IMAGE"]],
             "flash_kernel": [["fastboot", "flash", "$PARTITION_KERNEL",
                               "$BOOT/boot.img$FLAVOR"]],
@@ -909,7 +965,7 @@ flashers = {
         "depends": ["android-tools"],
         "actions": {
             "list_devices": [["fastboot", "devices", "-l"]],
-            "flash_rootfs": [["fastboot", "flash", "$PARTITION_SYSTEM",
+            "flash_rootfs": [["fastboot", "flash", "$PARTITION_ROOTFS",
                               "$IMAGE_SPLIT_ROOT"]],
             "flash_kernel": [["fastboot", "flash", "$PARTITION_KERNEL",
                               "$IMAGE_SPLIT_BOOT"]],
@@ -927,7 +983,7 @@ flashers = {
             "list_devices": [["heimdall", "detect"]],
             "flash_rootfs": [
                 ["heimdall_wait_for_device.sh"],
-                ["heimdall", "flash", "--$PARTITION_SYSTEM", "$IMAGE"]],
+                ["heimdall", "flash", "--$PARTITION_ROOTFS", "$IMAGE"]],
             "flash_kernel": [["heimdall_flash_kernel.sh",
                               "$BOOT/initramfs$FLAVOR", "$PARTITION_INITFS",
                               "$BOOT/vmlinuz$FLAVOR$DTB",
@@ -942,7 +998,7 @@ flashers = {
             "list_devices": [["heimdall", "detect"]],
             "flash_rootfs": [
                 ["heimdall_wait_for_device.sh"],
-                ["heimdall", "flash", "--$PARTITION_SYSTEM", "$IMAGE"]],
+                ["heimdall", "flash", "--$PARTITION_ROOTFS", "$IMAGE"]],
             "flash_kernel": [
                 ["heimdall_wait_for_device.sh"],
                 ["heimdall", "flash", "--$PARTITION_KERNEL",
@@ -985,7 +1041,7 @@ flashers = {
         "actions": {
             "list_devices": [["rkdeveloptool", "list"]],
             "flash_rootfs": [
-                ["rkdeveloptool", "write-partition", "$PARTITION_SYSTEM",
+                ["rkdeveloptool", "write-partition", "$PARTITION_ROOTFS",
                     "$IMAGE_SPLIT_ROOT"]
             ],
             "flash_kernel": [
@@ -993,6 +1049,27 @@ flashers = {
                     "$IMAGE_SPLIT_BOOT"]
             ],
         },
+    },
+    "mtkclient": {
+        "depends": ["mtkclient"],
+        "actions": {
+            "flash_rootfs": [["mtk", "w", "$PARTITION_ROOTFS",
+                              "$IMAGE"]],
+            "flash_kernel": [["mtk", "w", "$PARTITION_KERNEL",
+                              "$BOOT/boot.img$FLAVOR"]],
+            "flash_vbmeta": [
+                # Generate vbmeta image with "disable verification" flag
+                ["avbtool", "make_vbmeta_image", "--flags", "2",
+                    "--padding_size", "$FLASH_PAGESIZE",
+                    "--output", "/vbmeta.img"],
+                ["mtk", "w", "$PARTITION_VBMETA", "/vbmeta.img"],
+                ["rm", "-f", "/vbmeta.img"]
+            ],
+            "flash_dtbo": [["mtk", "w", "$PARTITION_DTBO",
+                            "$BOOT/dtbo.img"]],
+            "flash_lk2nd": [["mtk", "w", "$PARTITION_KERNEL",
+                             "$BOOT/lk2nd.img"]]
+        }
     }
 }
 
@@ -1013,7 +1090,7 @@ git_repo_outdated = 3600 * 24 * 2
 #
 aportgen = {
     "cross": {
-        "prefixes": ["binutils", "busybox-static", "gcc", "musl", "grub-efi"],
+        "prefixes": ["busybox-static", "gcc", "musl", "grub-efi"],
         "confirm_overwrite": False,
     },
     "device/testing": {
