@@ -1,4 +1,4 @@
-# Copyright 2022 Oliver Smith
+# Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import pmb.chroot.apk
 import pmb.config
@@ -32,6 +32,10 @@ def install_depends(args):
         pmaports_cfg = pmb.config.pmaports.read_config(args)
         depends = pmaports_cfg.get("supported_heimdall_depends",
                                    "heimdall,avbtool").split(",")
+    elif method == "mtkclient":
+        pmaports_cfg = pmb.config.pmaports.read_config(args)
+        depends = pmaports_cfg.get("supported_mtkclient_depends",
+                                   "mtkclient,android-tools").split(",")
 
     pmb.chroot.apk.install(args, depends)
 
