@@ -1,4 +1,4 @@
-# Copyright 2021 Oliver Smith
+# Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import os
 import glob
@@ -59,7 +59,7 @@ def list_apkbuilds(args):
     ret = {}
     for device in list_codenames(args):
         apkbuild_path = f"{args.aports}/device/*/device-{device}/APKBUILD"
-        ret[device] = pmb.parse.apkbuild(args, apkbuild_path)
+        ret[device] = pmb.parse.apkbuild(apkbuild_path)
     return ret
 
 
