@@ -2,12 +2,13 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 import fcntl
 import logging
+import os
 import selectors
+import shlex
 import subprocess
 import sys
 import threading
 import time
-import os
 import pmb.helpers.run
 
 """ For a detailed description of all output modes, read the description of
@@ -15,6 +16,35 @@ import pmb.helpers.run
     called by core(). """
 
 
+def flat_cmd(cmd, working_dir=None, env={}):
+    """
+    Convert a shell command passed as list into a flat shell string with
+    proper escaping.
+
+    :param cmd: command as list, e.g. ["echo", "string with spaces"]
+    :param working_dir: when set, prepend "cd ...;" to execute the command
+                        in the given working directory
+    :param env: dict of environment variables to be passed to the command, e.g.
+                {"JOBS": "5"}
+    :returns: the flat string, e.g.
+              echo 'string with spaces'
+              cd /home/pmos;echo 'string with spaces'
+    """
+    # Merge env and cmd into escaped list
+    escaped = []
+    for key, value in env.items():
+        escaped.append(key + "=" + shlex.quote(value))
+    for i in range(len(cmd)):
+        escaped.append(shlex.quote(cmd[i]))
+
+    # Prepend working dir
+    ret = " ".join(escaped)
+    if working_dir:
+        ret = "cd " + shlex.quote(working_dir) + ";" + ret
+
+    return ret
+
+
 def sanity_checks(output="log", output_return=False, check=None):
     """
     Raise an exception if the parameters passed to core() don't make sense
@@ -227,10 +257,10 @@ def sudo_timer_iterate():
     Run sudo -v and schedule a new timer to repeat the same.
     """
 
-    if pmb.config.sudo == "sudo":
+    if pmb.config.which_sudo() == "sudo":
         subprocess.Popen(["sudo", "-v"]).wait()
     else:
-        subprocess.Popen([pmb.config.sudo, "true"]).wait()
+        subprocess.Popen(pmb.config.sudo(["true"])).wait()
 
     timer = threading.Timer(interval=60, function=sudo_timer_iterate)
     timer.daemon = True
@@ -288,7 +318,7 @@ def core(args, log_message, cmd, working_dir=None, output="log",
                    output value  | timeout | out to log | out to stdout | wait | pass stdin
                    ------------------------------------------------------------------------
                    "log"         | x       | x          |               | x    |
-                   "stdout"      | x       | x          | x             | x    | x
+                   "stdout"      | x       | x          | x             | x    |
                    "interactive" |         | x          | x             | x    | x
                    "tui"         |         |            | x             | x    | x
                    "background"  |         | x          |               |      |
@@ -310,6 +340,15 @@ def core(args, log_message, cmd, working_dir=None, output="log",
     """
     sanity_checks(output, output_return, check)
 
+    # Preserve proxy environment variables
+    env = {}
+    for var in ["FTP_PROXY", "ftp_proxy", "HTTP_PROXY", "http_proxy",
+                "HTTPS_PROXY", "https_proxy", "HTTP_PROXY_AUTH"]:
+        if var in os.environ:
+            env[var] = os.environ[var]
+    if env:
+        cmd = ["sh", "-c", flat_cmd(cmd, env=env)]
+
     if args.sudo_timer and sudo:
         sudo_timer_start()
 
@@ -338,7 +377,7 @@ def core(args, log_message, cmd, working_dir=None, output="log",
 
         output_timeout = output in ["log", "stdout"] and not disable_timeout
 
-        stdin = subprocess.DEVNULL if output == "log" else None
+        stdin = subprocess.DEVNULL if output in ["log", "stdout"] else None
 
         (code, output_after_run) = foreground_pipe(args, cmd, working_dir,
                                                    output_to_stdout,
