@@ -164,8 +164,8 @@ def create_home_from_skel(args):
 def configure_apk(args):
     """
     Copy over all official keys, and the keys used to compile local packages
-    (unless --no-local-pkgs is set). Then disable the /mnt/pmbootstrap-packages
-    repository.
+    (unless --no-local-pkgs is set). Then copy the corresponding APKINDEX files
+    and remove the /mnt/pmbootstrap/packages repository.
     """
     # Official keys
     pattern = f"{pmb.config.apk_keys_path}/*.pub"
@@ -179,8 +179,15 @@ def configure_apk(args):
     for key in glob.glob(pattern):
         pmb.helpers.run.root(args, ["cp", key, rootfs + "/etc/apk/keys/"])
 
+    # Copy over the corresponding APKINDEX files from cache
+    index_files = pmb.helpers.repo.apkindex_files(args,
+                                                  arch=args.deviceinfo["arch"],
+                                                  user_repository=False)
+    for f in index_files:
+        pmb.helpers.run.root(args, ["cp", f, rootfs + "/var/cache/apk/"])
+
     # Disable pmbootstrap repository
-    pmb.helpers.run.root(args, ["sed", "-i", r"/\/mnt\/pmbootstrap-packages/d",
+    pmb.helpers.run.root(args, ["sed", "-i", r"/\/mnt\/pmbootstrap\/packages/d",
                                 rootfs + "/etc/apk/repositories"])
     pmb.helpers.run.user(args, ["cat", rootfs + "/etc/apk/repositories"])
 
@@ -197,7 +204,13 @@ def set_user(args):
     if not pmb.chroot.user_exists(args, args.user, suffix):
         pmb.chroot.root(args, ["adduser", "-D", "-u", "10000", args.user],
                         suffix)
-    groups = pmb.install.ui.get_groups(args) + pmb.config.install_user_groups
+
+    pmaports_cfg = pmb.config.pmaports.read_config(args)
+    groups = []
+    groups += pmaports_cfg.get("install_user_groups",
+                               "audio,input,netdev,plugdev,video,wheel").split(",")
+    groups += pmb.install.ui.get_groups(args)
+
     for group in groups:
         pmb.chroot.root(args, ["addgroup", "-S", group], suffix,
                         check=False)
@@ -347,6 +360,26 @@ def setup_keymap(args):
         logging.info("NOTE: No valid keymap specified for device")
 
 
+def setup_timezone(args):
+    suffix = f"rootfs_{args.device}"
+
+    arch = args.deviceinfo["arch"]
+    alpine_conf = pmb.helpers.package.get(args, "alpine-conf", arch)
+    version = alpine_conf["version"].split("-r")[0]
+
+    setup_tz_cmd = ["setup-timezone"]
+    # setup-timezone will, by default, copy the timezone to /etc/zoneinfo
+    # and disregard tzdata, to save space. If we actually have tzdata
+    # installed, make sure that setup-timezone makes use of it, since
+    # there's no space to be saved.
+    if "tzdata" in pmb.chroot.apk.installed(args, suffix):
+        setup_tz_cmd += ["-i"]
+    if not pmb.parse.version.check_string(version, ">=3.14.0"):
+        setup_tz_cmd += ["-z"]
+    setup_tz_cmd += [args.timezone]
+    pmb.chroot.root(args, setup_tz_cmd, suffix)
+
+
 def setup_hostname(args):
     """
     Set the hostname and update localhost address in /etc/hosts
@@ -370,6 +403,25 @@ def setup_hostname(args):
     pmb.chroot.root(args, ["sed", "-i", "-e", regex, "/etc/hosts"], suffix)
 
 
+def setup_appstream(args):
+    """
+    If alpine-appstream-downloader has been downloaded, execute it to have
+    update AppStream data on new installs
+    """
+    suffix = "rootfs_" + args.device
+    installed_pkgs = pmb.chroot.apk.installed(args, suffix)
+
+    if "alpine-appstream-downloader" not in installed_pkgs or args.offline:
+        return
+
+    pmb.chroot.root(args, ["alpine-appstream-downloader",
+                           "/mnt/appstream-data"], suffix)
+    pmb.chroot.root(args, ["mkdir", "-p", "/var/lib/swcatalog"], suffix)
+    pmb.chroot.root(args, ["cp", "-r", "/mnt/appstream-data/icons",
+                           "/mnt/appstream-data/xml",
+                           "-t", "/var/lib/swcatalog"], suffix)
+
+
 def disable_sshd(args):
     if not args.no_sshd:
         return
@@ -560,7 +612,7 @@ def write_cgpt_kpart(args, layout, suffix):
     :param layout: partition layout from get_partition_layout()
     :param suffix: of the chroot, which holds the image file to be flashed
     """
-    if not args.deviceinfo["cgpt_kpart"]:
+    if not args.deviceinfo["cgpt_kpart"] or not args.install_cgpt:
         return
 
     device_rootfs = mount_device_rootfs(args, suffix)
@@ -569,20 +621,20 @@ def write_cgpt_kpart(args, layout, suffix):
         args, ["dd", f"if={filename}", f"of=/dev/installp{layout['kernel']}"])
 
 
-def sanity_check_sdcard(args):
-    device = args.sdcard
+def sanity_check_disk(args):
+    device = args.disk
     device_name = os.path.basename(device)
     if not os.path.exists(device):
-        raise RuntimeError(f"{device} doesn't exist, is the sdcard plugged?")
+        raise RuntimeError(f"{device} doesn't exist, is the disk plugged?")
     if os.path.isdir('/sys/class/block/{}'.format(device_name)):
         with open('/sys/class/block/{}/ro'.format(device_name), 'r') as handle:
             ro = handle.read()
         if ro == '1\n':
-            raise RuntimeError(f"{device} is read-only, is the sdcard locked?")
+            raise RuntimeError(f"{device} is read-only, maybe a locked SD card?")
 
 
-def sanity_check_sdcard_size(args):
-    device = args.sdcard
+def sanity_check_disk_size(args):
+    device = args.disk
     devpath = os.path.realpath(device)
     sysfs = '/sys/class/block/{}/size'.format(devpath.replace('/dev/', ''))
     if not os.path.isfile(sysfs):
@@ -648,9 +700,77 @@ def get_partition_layout(reserve, kernel):
     return ret
 
 
+def get_uuid(args, partition):
+    """
+    Get UUID of a partition
+
+    :param partition: block device for getting UUID from
+    """
+    return pmb.chroot.root(
+        args,
+        [
+            "blkid",
+            "-s", "UUID",
+            "-o", "value",
+            partition,
+        ],
+        output_return=True
+    ).rstrip()
+
+
+def create_crypttab(args, layout, suffix):
+    """
+    Create /etc/crypttab config
+
+    :param layout: partition layout from get_partition_layout()
+    :param suffix: of the chroot, which crypttab will be created to
+    """
+
+    luks_uuid = get_uuid(args, f"/dev/installp{layout['root']}")
+
+    crypttab = f"root UUID={luks_uuid} none luks\n"
+
+    open(f"{args.work}/chroot_{suffix}/tmp/crypttab", "w").write(crypttab)
+    pmb.chroot.root(args, ["mv", "/tmp/crypttab", "/etc/crypttab"], suffix)
+
+
+def create_fstab(args, layout, suffix):
+    """
+    Create /etc/fstab config
+
+    :param layout: partition layout from get_partition_layout()
+    :param suffix: of the chroot, which fstab will be created to
+    """
+
+    # Do not install fstab into target rootfs when using on-device
+    # installer. Provide fstab only to installer suffix
+    if args.on_device_installer and "rootfs_" in suffix:
+        return
+
+    boot_dev = f"/dev/installp{layout['boot']}"
+    root_dev = f"/dev/installp{layout['root']}"
+
+    boot_mount_point = f"UUID={get_uuid(args, boot_dev)}"
+    root_mount_point = "/dev/mapper/root" if args.full_disk_encryption \
+        else f"UUID={get_uuid(args, root_dev)}"
+
+    boot_filesystem = args.deviceinfo["boot_filesystem"] or "ext2"
+    root_filesystem = pmb.install.get_root_filesystem(args)
+
+    fstab = f"""
+# <file system> <mount point> <type> <options> <dump> <pass>
+{root_mount_point} / {root_filesystem} defaults 0 0
+{boot_mount_point} /boot {boot_filesystem} defaults 0 0
+""".lstrip()
+
+    with open(f"{args.work}/chroot_{suffix}/tmp/fstab", "w") as f:
+        f.write(fstab)
+    pmb.chroot.root(args, ["mv", "/tmp/fstab", "/etc/fstab"], suffix)
+
+
 def install_system_image(args, size_reserve, suffix, step, steps,
                          boot_label="pmOS_boot", root_label="pmOS_root",
-                         split=False, sdcard=None):
+                         split=False, disk=None):
     """
     :param size_reserve: empty partition between root and boot in MiB (pma#463)
     :param suffix: the chroot suffix, where the rootfs that will be installed
@@ -660,26 +780,43 @@ def install_system_image(args, size_reserve, suffix, step, steps,
     :param boot_label: label of the boot partition (e.g. "pmOS_boot")
     :param root_label: label of the root partition (e.g. "pmOS_root")
     :param split: create separate images for boot and root partitions
-    :param sdcard: path to sdcard device (e.g. /dev/mmcblk0) or None
+    :param disk: path to disk block device (e.g. /dev/mmcblk0) or None
     """
-    # Partition and fill image/sdcard
+    # Partition and fill image file/disk block device
     logging.info(f"*** ({step}/{steps}) PREPARE INSTALL BLOCKDEVICE ***")
     pmb.chroot.shutdown(args, True)
     (size_boot, size_root) = get_subpartitions_size(args, suffix)
-    layout = get_partition_layout(size_reserve, args.deviceinfo["cgpt_kpart"])
+    layout = get_partition_layout(size_reserve, args.deviceinfo["cgpt_kpart"] \
+             and args.install_cgpt)
     if not args.rsync:
         pmb.install.blockdevice.create(args, size_boot, size_root,
-                                       size_reserve, split, sdcard)
+                                       size_reserve, split, disk)
         if not split:
-            if args.deviceinfo["cgpt_kpart"]:
+            if args.deviceinfo["cgpt_kpart"] and args.install_cgpt:
                 pmb.install.partition_cgpt(
                     args, layout, size_boot, size_reserve)
             else:
                 pmb.install.partition(args, layout, size_boot, size_reserve)
     if not split:
-        pmb.install.partitions_mount(args, layout, sdcard)
+        pmb.install.partitions_mount(args, layout, disk)
 
-    pmb.install.format(args, layout, boot_label, root_label, sdcard)
+    pmb.install.format(args, layout, boot_label, root_label, disk)
+
+    # Create /etc/fstab and /etc/crypttab
+    logging.info("(native) create /etc/fstab")
+    create_fstab(args, layout, suffix)
+    if args.full_disk_encryption:
+        logging.info("(native) create /etc/crypttab")
+        create_crypttab(args, layout, suffix)
+
+    # Run mkinitfs to pass UUIDs to cmdline
+    logging.info(f"({suffix}) mkinitfs")
+    pmb.chroot.root(args, ["mkinitfs"], suffix)
+
+    # Clean up after running mkinitfs in chroot
+    pmb.helpers.mount.umount_all(args, f"{args.work}/chroot_{suffix}")
+    pmb.helpers.run.root(args, ["rm", f"{args.work}/chroot_{suffix}/in-pmbootstrap"])
+    pmb.chroot.remove_mnt_pmbootstrap(args, suffix)
 
     # Just copy all the files
     logging.info(f"*** ({step + 1}/{steps}) FILL INSTALL BLOCKDEVICE ***")
@@ -694,8 +831,8 @@ def install_system_image(args, size_reserve, suffix, step, steps,
         embed_firmware(args, suffix)
         write_cgpt_kpart(args, layout, suffix)
 
-    if sdcard:
-        logging.info("Unmounting SD card (this may take a while "
+    if disk:
+        logging.info(f"Unmounting disk {disk} (this may take a while "
                      "to sync, please wait)")
     pmb.chroot.shutdown(args, True)
 
@@ -704,7 +841,7 @@ def install_system_image(args, size_reserve, suffix, step, steps,
     if sparse is None:
         sparse = args.deviceinfo["flash_sparse"] == "true"
 
-    if sparse and not split and not sdcard:
+    if sparse and not split and not disk:
         logging.info("(native) make sparse rootfs")
         pmb.chroot.apk.install(args, ["android-tools"])
         sys_image = args.device + ".img"
@@ -750,7 +887,7 @@ def print_flash_info(args):
     logging.info("Run the following to flash your installation to the"
                  " target device:")
 
-    if "flash_rootfs" in flasher_actions and not args.sdcard and \
+    if "flash_rootfs" in flasher_actions and not args.disk and \
             bool(args.split) == requires_split:
         logging.info("* pmbootstrap flasher flash_rootfs")
         logging.info("  Flashes the generated rootfs image to your device:")
@@ -783,8 +920,8 @@ def print_flash_info(args):
 
     # Most flash methods operate independently of the boot partition.
     # (e.g. an Android boot image is generated). In that case, "flash_kernel"
-    # works even when partitions are split or installing for sdcard.
-    # This is not possible if the flash method requires split partitions.
+    # works even when partitions are split or installing to disk. This is not
+    # possible if the flash method requires split partitions.
     if "flash_kernel" in flasher_actions and \
             (not requires_split or args.split):
         logging.info("* pmbootstrap flasher flash_kernel")
@@ -867,7 +1004,7 @@ def install_on_device_installer(args, step, steps):
            "ONDEV_CHANNEL_DESCRIPTION": channel_cfg["description"],
            "ONDEV_CHANNEL_MIRRORDIR_ALPINE": channel_cfg["mirrordir_alpine"],
            "ONDEV_CIPHER": args.cipher,
-           "ONDEV_PMBOOTSTRAP_VERSION": pmb.config.version,
+           "ONDEV_PMBOOTSTRAP_VERSION": pmb.__version__,
            "ONDEV_UI": args.ui}
     pmb.chroot.root(args, ["ondev-prepare"], suffix_installer, env=env)
 
@@ -896,7 +1033,7 @@ def install_on_device_installer(args, step, steps):
     boot_label = pmaports_cfg.get("supported_install_boot_label",
                                   "pmOS_inst_boot")
     install_system_image(args, size_reserve, suffix_installer, step, steps,
-                         boot_label, "pmOS_install", args.split, args.sdcard)
+                         boot_label, "pmOS_install", args.split, args.disk)
 
 
 def get_selected_providers(args, packages):
@@ -995,33 +1132,31 @@ def create_device_rootfs(args, step, steps):
     setup_keymap(args)
 
     # Set timezone
-    arch = args.deviceinfo["arch"]
-    package = pmb.helpers.package.get(args, "alpine-conf", arch)
-    version = package["version"].split("-r")[0]
-
-    if not pmb.parse.version.check_string(version, ">=3.14.0"):
-        pmb.chroot.root(args, ["setup-timezone", "-z", args.timezone], suffix)
-    else:
-        pmb.chroot.root(args, ["setup-timezone", args.timezone], suffix)
+    setup_timezone(args)
 
     # Set locale
     if locale_is_set:
-        pmb.chroot.root(args, ["sed", "-i",
-                               f"s/LANG=C.UTF-8/LANG={args.locale}/",
-                               "/etc/profile.d/locale.sh"], suffix)
+        # 10locale-pmos.sh gets sourced before 20locale.sh from
+        # alpine-baselayout by /etc/profile. Since they don't override the
+        # locale if it exists, it warranties we have preference
+        line = f"export LANG=${{LANG:-{shlex.quote(args.locale)}}}"
+        pmb.chroot.root(args, ["sh", "-c", f"echo {shlex.quote(line)}"
+                               " > /etc/profile.d/10locale-pmos.sh"], suffix)
 
     # Set the hostname as the device name
     setup_hostname(args)
 
+    setup_appstream(args)
+
     disable_sshd(args)
     disable_firewall(args)
 
 
 def install(args):
     # Sanity checks
-    if not args.android_recovery_zip and args.sdcard:
-        sanity_check_sdcard(args)
-        sanity_check_sdcard_size(args)
+    if not args.android_recovery_zip and args.disk:
+        sanity_check_disk(args)
+        sanity_check_disk_size(args)
     if args.on_device_installer:
         sanity_check_ondev_version(args)
 
@@ -1056,7 +1191,7 @@ def install(args):
         install_on_device_installer(args, step, steps)
     else:
         install_system_image(args, 0, f"rootfs_{args.device}", step, steps,
-                             split=args.split, sdcard=args.sdcard)
+                             split=args.split, disk=args.disk)
 
     print_flash_info(args)
     print_sshd_info(args)
