@@ -1,6 +1,6 @@
 # Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
-from pmb.parse.arguments import arguments
+from pmb.parse.arguments import arguments, arguments_install, arguments_flasher
 from pmb.parse._apkbuild import apkbuild
 from pmb.parse._apkbuild import function_body
 from pmb.parse.binfmt_info import binfmt_info
