@@ -1,4 +1,4 @@
-# Copyright 2022 Oliver Smith
+# Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import logging
 import os
@@ -320,8 +320,7 @@ def apkbuild(path, check_pkgver=True, check_pkgname=True):
 
     # Sanity check: pkgver
     if check_pkgver:
-        if ("-r" in ret["pkgver"] or not
-           pmb.parse.version.validate(ret["pkgver"])):
+        if not pmb.parse.version.validate(ret["pkgver"]):
             logging.info(
                 "NOTE: Valid pkgvers are described here: "
                 "https://wiki.alpinelinux.org/wiki/APKBUILD_Reference#pkgver")
