@@ -79,6 +79,8 @@ def arguments_install(subparser):
                      " installation - will be handled in PLAIN TEXT during"
                      " install and may be logged to the logfile, do not use an"
                      " important password!")
+    ret.add_argument("--no-cgpt", help="do not use cgpt partition table",
+                     dest="install_cgpt", action="store_false", default=True)
 
     # Image type
     group_desc = ret.add_argument_group(
@@ -94,9 +96,11 @@ def arguments_install(subparser):
                        default=None)
     group.add_argument("--split", help="create separate boot and root image"
                        " files", action="store_true")
-    group.add_argument("--sdcard", help="do not create an image file, instead"
-                       " write to the given SD card device (e.g."
-                       " '/dev/mmcblk0')", metavar="BLOCKDEV")
+    group.add_argument("--disk", "--sdcard",
+                       help="do not create an image file, instead"
+                            " write to the given block device (SD card, USB"
+                            " stick, etc.), for example: '/dev/mmcblk0'",
+                       metavar="BLOCKDEV")
     group.add_argument("--android-recovery-zip",
                        help="generate TWRP flashable zip (recommended read:"
                             " https://postmarketos.org/recoveryzip)",
@@ -104,9 +108,9 @@ def arguments_install(subparser):
     group.add_argument("--no-image", help="do not generate an image",
                        action="store_true", dest="no_image")
 
-    # Image type "--sdcard" related
-    group = ret.add_argument_group("optional image type 'sdcard' arguments")
-    group.add_argument("--rsync", help="update the SD card using rsync",
+    # Image type "--disk" related
+    group = ret.add_argument_group("optional image type 'disk' arguments")
+    group.add_argument("--rsync", help="update the disk using rsync",
                        action="store_true")
 
     # Image type "--android-recovery-zip" related
@@ -250,13 +254,13 @@ def arguments_flasher(subparser):
                              " default boot image partition ")
 
     # Flash rootfs
-    flash_rootfs = sub.add_parser("flash_rootfs", aliases=["flash_system"],
+    flash_rootfs = sub.add_parser("flash_rootfs",
                                   help="flash the rootfs to a partition on the"
                                   " device (partition layout does not get"
                                   " changed)")
     flash_rootfs.add_argument("--partition", default=None,
                               help="partition to flash the rootfs to (defaults"
-                                   " to deviceinfo_flash_*_partition_system,"
+                                   " to deviceinfo_flash_*_partition_rootfs,"
                                    " 'userdata' on Android may have more"
                                    " space)")
 
@@ -366,6 +370,8 @@ def arguments_qemu(subparser):
     ret.add_argument("--host-qemu", dest="host_qemu", action='store_true',
                      help="Use the host system's qemu")
 
+    ret.add_argument("--efi", action="store_true",
+                     help="Use EFI boot (default: direct kernel image boot)")
     return ret
 
 
@@ -462,26 +468,17 @@ def arguments_kconfig(subparser):
                        " kernels, even the ones that would be ignored by"
                        " default")
     check.add_argument("--arch", choices=arch_choices, dest="arch")
-    check.add_argument("--file", action="store_true", help="check a file"
-                       " directly instead of a config in a package")
-    check.add_argument("--waydroid", action="store_true", help="check"
-                       " options needed for waydroid too")
-    check.add_argument("--iwd", action="store_true", help="check"
-                       " options needed for iwd too")
-    check.add_argument("--nftables", action="store_true", help="check"
-                       " options needed for nftables too")
-    check.add_argument("--containers", action="store_true",
-                       help="check options needed for containers too")
-    check.add_argument("--zram", action="store_true", help="check"
-                       " options needed for zram support too")
-    check.add_argument("--netboot", action="store_true", help="check"
-                       " options needed for netbooting too")
-    check.add_argument("--community", action="store_true", help="check"
-                       " options needed for various features, required for"
-                       " community/main devices")
-    check.add_argument("--uefi", action="store_true", help="check"
-                       " options needed for uefi too")
-    add_kernel_arg(check)
+    check.add_argument("--file", help="check a file directly instead of a"
+                       " config in a package")
+    check.add_argument("--no-details", action="store_false",
+                       dest="kconfig_check_details",
+                       help="print one generic error per component instead of"
+                            " listing each option that needs to be adjusted")
+    for name in pmb.parse.kconfig.get_all_component_names():
+        check.add_argument(f"--{name}", action="store_true",
+                           dest=f"kconfig_check_{name}",
+                           help=f"check options needed for {name} too")
+    add_kernel_arg(check, nargs="*")
 
     # "pmbootstrap kconfig edit"
     edit = sub.add_parser("edit", help="edit kernel aport config")
@@ -595,8 +592,8 @@ def add_packages_arg(subparser, name="packages", *args, **kwargs):
         arg.completer = package_completer
 
 
-def add_kernel_arg(subparser, name="package", *args, **kwargs):
-    arg = subparser.add_argument("package", nargs='?', help="kernel package"
+def add_kernel_arg(subparser, name="package", nargs="?", *args, **kwargs):
+    arg = subparser.add_argument("package", nargs=nargs, help="kernel package"
                                  " (e.g. linux-postmarketos-allwinner)")
     if argcomplete:
         arg.completer = kernel_completer
@@ -610,7 +607,7 @@ def arguments():
 
     # Other
     parser.add_argument("-V", "--version", action="version",
-                        version=pmb.config.version)
+                        version=pmb.__version__)
     parser.add_argument("-c", "--config", dest="config",
                         default=pmb.config.defaults["config"],
                         help="path to pmbootstrap.cfg file (default in"
@@ -618,7 +615,6 @@ def arguments():
     parser.add_argument("--config-channels",
                         help="path to channels.cfg (which is by default"
                              " read from pmaports.git, origin/master branch)")
-    parser.add_argument("-d", "--port-distccd", dest="port_distccd")
     parser.add_argument("-mp", "--mirror-pmOS", dest="mirrors_postmarketos",
                         help="postmarketOS mirror, disable with: -mp='',"
                              " specify multiple with: -mp='one' -mp='two',"
@@ -659,16 +655,6 @@ def arguments():
     # Compiler
     parser.add_argument("--no-ccache", action="store_false",
                         dest="ccache", help="do not cache the compiled output")
-    parser.add_argument("--no-crossdirect", action="store_true",
-                        help="Don't use the new, faster 'crossdirect' method,"
-                             " use the old 'distcc-sshd' method instead. Use"
-                             " if crossdirect broke something. This option"
-                             " and the legacy 'distcc-sshd' code will be"
-                             " removed soon if no problems turn up.")
-    parser.add_argument("--distcc-nofallback", action="store_false",
-                        help="when using the cross compiler via distcc fails,"
-                             "do not fall back to compiling slowly with QEMU",
-                        dest="distcc_fallback")
     parser.add_argument("--no-cross", action="store_false", dest="cross",
                         help="disable cross compiler, build only with QEMU and"
                              " gcc (slow!)")
@@ -712,14 +698,10 @@ def arguments():
 
     # Action: log
     log = sub.add_parser("log", help="follow the pmbootstrap logfile")
-    log_distccd = sub.add_parser(
-        "log_distccd",
-        help="follow the distccd logfile")
-    for action in [log, log_distccd]:
-        action.add_argument("-n", "--lines", default="60",
-                            help="count of initial output lines")
-        action.add_argument("-c", "--clear", help="clear the log",
-                            action="store_true", dest="clear_log")
+    log.add_argument("-n", "--lines", default="60",
+                     help="count of initial output lines")
+    log.add_argument("-c", "--clear", help="clear the log",
+                     action="store_true", dest="clear_log")
 
     # Action: zap
     zap = sub.add_parser("zap", help="safely delete chroot folders")
@@ -855,6 +837,18 @@ def arguments():
     build.add_argument("-n", "--no-depends", action="store_true",
                        help="never build dependencies, abort instead",
                        dest="no_depends")
+    build.add_argument("--go-mod-cache", action="store_true", default=None,
+                       help="for go packages: Usually they should bundle the"
+                            " dependency sources instead of downloading them"
+                            " at build time. But if they don't (e.g. with"
+                            " pmbootstrap build --src), then this option can"
+                            " be used to let GOMODCACHE point into"
+                            " pmbootstrap's work dir to only download"
+                            " dependencies once. (default: true with --src,"
+                            " false otherwise)")
+    build.add_argument("--no-go-mod-cache",
+                       action="store_false", dest="go_mod_cache", default=None,
+                       help="don't set GOMODCACHE")
     build.add_argument("--envkernel", action="store_true",
                        help="Create an apk package from the build output of"
                        " a kernel compiled locally on the host or with envkernel.sh.")
@@ -909,4 +903,9 @@ def arguments():
     setattr(args, "from_argparse", copy.deepcopy(args))
     setattr(args.from_argparse, "from_argparse", args.from_argparse)
     pmb.helpers.args.init(args)
+
+    if getattr(args, "go_mod_cache", None) is None:
+        gomodcache = True if getattr(args, "src", None) else False
+        setattr(args, "go_mod_cache", gomodcache)
+
     return args
