@@ -5,6 +5,7 @@ import os
 
 import pmb.helpers.git
 import pmb.helpers.run
+import shutil
 
 
 def prepare_tmpdir(args, monkeypatch, tmpdir):
@@ -34,16 +35,16 @@ def prepare_tmpdir(args, monkeypatch, tmpdir):
 
     def run_git(git_args, repo="local"):
         path = tmpdir + "/" + repo
-        pmb.helpers.run.user(args, ["git"] + git_args, path, "stdout")
+        pmb.helpers.run.user(args, ["git"] + git_args, path, "stdout", output_return=True)
 
     # Remote repos
-    run_git(["init", "."], "remote")
+    run_git(["init", "-b", "master", "."], "remote")
     run_git(["commit", "--allow-empty", "-m", "commit: remote"], "remote")
-    run_git(["init", "."], "remote2")
+    run_git(["init", "-b", "master", "."], "remote2")
     run_git(["commit", "--allow-empty", "-m", "commit: remote2"], "remote2")
 
     # Local repo (with master -> origin2/master)
-    run_git(["init", "."])
+    run_git(["init", "-b", "master", "."])
     run_git(["remote", "add", "-f", "origin", path_remote])
     run_git(["remote", "add", "-f", "origin2", path_remote2])
     run_git(["checkout", "-b", "master", "--track", "origin2/master"])
@@ -59,3 +60,6 @@ def prepare_tmpdir(args, monkeypatch, tmpdir):
     monkeypatch.setattr(pmb.helpers.git, "get_upstream_remote", get_u_r)
 
     return path_local, run_git
+
+def copy_dotgit(args, tmpdir):
+    shutil.copytree(args.aports + "/.git", tmpdir + "/.git", ignore_dangling_symlinks=True)
