@@ -4,10 +4,10 @@
 import glob
 import os
 import pytest
-import shutil
 import sys
 
 import pmb_test  # noqa
+import pmb_test.git
 import pmb.helpers.pkgrel_bump
 import pmb.helpers.logging
 
@@ -39,7 +39,7 @@ def pmbootstrap(args, tmpdir, parameters, zero_exit=True):
     # Copy .git dir to fake pmaports
     dot_git = tmpdir + "/_aports/.git"
     if not os.path.exists(dot_git):
-        shutil.copytree(args.aports + "/.git", dot_git)
+        pmb_test.git.copy_dotgit(args, aports)
 
     try:
         pmb.helpers.run.user(args, ["./pmbootstrap.py", "--work=" + tmpdir,
@@ -128,6 +128,9 @@ def test_pkgrel_bump_high_level(args, tmpdir):
     tmpdir = str(tmpdir)
     setup_work(args, tmpdir)
 
+    # Make sure we don't try and cross compile
+    pmbootstrap(args, tmpdir, ["config", "build_default_device_arch", "False"])
+
     # Let pkgrel_bump exit normally
     pmbootstrap(args, tmpdir, ["build", "testlib", "testapp", "testsubpkg"])
     pmbootstrap(args, tmpdir, ["pkgrel_bump", "--dry", "--auto"])
