@@ -1,10 +1,11 @@
 # Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 """ Test pmb.helpers.run_core """
-import re
-import sys
-import subprocess
+import os
 import pytest
+import re
+import subprocess
+import sys
 import time
 
 import pmb_test  # noqa
@@ -83,7 +84,7 @@ def test_foreground_pipe(args):
     assert ret == (-9, "first\n")
 
     # Kill with output timeout as root
-    cmd = [pmb.config.sudo, "sh", "-c", "printf first; sleep 2; printf second"]
+    cmd = pmb.config.sudo(["sh", "-c", "printf first; sleep 2; printf second"])
     args.timeout = 0.3
     ret = func(args, cmd, output_return=True, output_timeout=True,
                sudo=True)
@@ -99,9 +100,11 @@ def test_foreground_pipe(args):
     # Check if all child processes are killed after timeout.
     # The first command uses ps to get its process group id (pgid) and echo it
     # to stdout. All of the test commands will be running under that pgid.
-    cmd = [pmb.config.sudo, "sh", "-c",
-           "pgid=$(ps -o pgid= | grep ^${1:-$$});echo $pgid | tr -d '\n';" +
-           "sleep 10 | sleep 20 | sleep 30"]
+    cmd = pmb.config.sudo([
+        "sh", "-c",
+        "pgid=$(ps -o pgid= | grep ^${1:-$$});echo $pgid | tr -d '\n';"
+        "sleep 10 | sleep 20 | sleep 30"
+    ])
     args.timeout = 0.3
     ret = func(args, cmd, output_return=True, output_timeout=True,
                sudo=True)
@@ -125,7 +128,7 @@ def test_foreground_tui():
     assert func(["echo", "test"]) == 0
 
 
-def test_core(args):
+def test_core(args, monkeypatch):
     # Background
     func = pmb.helpers.run_core.core
     msg = "test"
@@ -155,6 +158,11 @@ def test_core(args):
         func(args, msg, ["sleep", "1"], output="log")
     assert re.search(r"^Command failed \(exit code -?\d*\): ", str(e.value))
 
+    # Preserve proxy environment variables
+    monkeypatch.setattr(os, "environ", {"FTP_PROXY": "testproxy"})
+    ret = func(args, msg, ["sh", "-c", 'echo "$FTP_PROXY"'], output_return=True)
+    assert ret == "testproxy\n"
+
 
 @pytest.mark.skip_ci
 def test_sudo_timer(args):
